@@ -1,4 +1,4 @@
-# Copyright (c) 2000, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2000, 2018, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -145,8 +145,8 @@
       %if "%elver" == "6" || "%elver" == "7"
         %define distro_description      Oracle Linux %elver
         %define distro_releasetag       el%elver
-        %define distro_buildreq         gcc-c++ ncurses-devel perl time zlib-devel cmake libaio-devel numactl-devel
-        %define distro_requires         chkconfig coreutils grep procps shadow-utils net-tools
+        %define distro_buildreq         gcc-c++ ncurses-devel perl perl(Data::Dumper) time zlib-devel cmake libaio-devel numactl-devel
+        %define distro_requires         chkconfig coreutils grep perl(Data::Dumper) procps shadow-utils net-tools
       %else
         %{error:Oracle Linux %{elver} is unsupported}
       %endif
@@ -168,8 +168,8 @@
             %if "%rhelver" == "6"
               %define distro_description    Red Hat Enterprise Linux 6
               %define distro_releasetag     rhel6
-              %define distro_buildreq       gcc-c++ ncurses-devel perl time zlib-devel cmake libaio-devel numactl-devel
-              %define distro_requires       chkconfig coreutils grep procps shadow-utils net-tools
+              %define distro_buildreq       gcc-c++ ncurses-devel perl perl(Data::Dumper) time zlib-devel cmake libaio-devel numactl-devel
+              %define distro_requires       chkconfig coreutils grep perl(Data::Dumper) procps shadow-utils net-tools
             %else
               %{error:Red Hat Enterprise Linux %{rhelver} is unsupported}
             %endif
@@ -203,8 +203,8 @@
   %define glibc_version %(/lib/libc.so.6 | grep stable | cut -d, -f1 | cut -c38-)
   %define distro_description            Generic Linux (glibc %{glibc_version})
   %define distro_releasetag             linux_glibc%{glibc_version}
-  %define distro_buildreq               gcc-c++ gperf ncurses-devel perl  time zlib-devel
-  %define distro_requires               coreutils grep procps /sbin/chkconfig /usr/sbin/useradd /usr/sbin/groupadd
+  %define distro_buildreq               gcc-c++ gperf ncurses-devel perl perl(Data::Dumper) time zlib-devel
+  %define distro_requires               coreutils grep perl(Data::Dumper) procps /sbin/chkconfig /usr/sbin/useradd /usr/sbin/groupadd
 %endif
 
 # Avoid debuginfo RPMs, leaves binaries unstripped
@@ -360,6 +360,7 @@ Obsoletes:      MySQL-test-classic MySQL-test-community MySQL-test-enterprise
 Obsoletes:      MySQL-test-advanced-gpl MySQL-test-enterprise-gpl
 Provides:       mysql-test = %{version}-%{release}
 Provides:       mysql-test%{?_isa} = %{version}-%{release}
+Requires:       perl(Data::Dumper)
 AutoReqProv:    no
 
 %description -n MySQL-test%{product_suffix}
@@ -604,12 +605,6 @@ install -m 644 "%{malloc_lib_source}" \
 # Remove man pages we explicitly do not want to package, avoids 'unpackaged
 # files' warning.
 # This has become obsolete:  rm -f $RBR%{_mandir}/man1/make_win_bin_dist.1*
-rm -f $RBR%{_mandir}/man1/mysql-stress-test.pl.1
-rm -f $RBR%{_mandir}/man1/mysql-test-run.pl.1
-rm -f $RBR%{_mandir}/man1/mysql_client_test.1
-rm -f $RBR%{_mandir}/man1/mysql_client_test_embedded.1
-rm -f $RBR%{_mandir}/man1/mysqltest.1
-rm -f $RBR%{_mandir}/man1/mysqltest_embedded.1
 
 ##############################################################################
 #  Post processing actions, i.e. when installed
@@ -1234,6 +1229,9 @@ echo "====="                                     >> $STATUS_HISTORY
 # merging BK trees)
 ##############################################################################
 %changelog
+* Wed Jan 10 2018 Bjorn Munch <bjorn.munch@oracle.com>
+- No longer need to remove obsoleted mysqltest man pages
+
 * Tue Oct 31 2017 Bjorn Munch <bjorn.munch@oracle.com>
 - Remove obsoleted mysqltest man pages
 
